=======
Credits
=======

Development Lead
----------------

* Odoo Community Association <support@odoo-community.org>

Contributors
------------

* Stefan Rijnhart
* David Béal
* Sylvain LE GAL
* Holger Brunn
* Sandy Carter
* Alexis de Lattre
* Arthur Vuillard
* Florent Xicluna
* Benoit Guillot
* Paulius Sladkevičius
* Florian Dacosta
* Alexandre Fayolle
* Pedro M. Baeza
* Manuel Vázquez Acosta
* Miku Laitinen
* Christoph Giesel
* Jordi Riera

